StdOutHandler (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.log
Class StdOutHandler

    java.lang.Object
      java.util.logging.Handler
          java.util.logging.StreamHandler
              org.openqa.selenium.server.log.StdOutHandler

    public class StdOutHandler

extends java.util.logging.StreamHandler

java.util.logging Log Handler logging everything to standard output.

Constructor Summary
`StdOutHandler()`

Method Summary
`void` | `publish(java.util.logging.LogRecord record)`

Methods inherited from class java.util.logging.StreamHandler
`close, flush, isLoggable, setEncoding, setOutputStream`

Methods inherited from class java.util.logging.Handler
`getEncoding, getErrorManager, getFilter, getFormatter, getLevel, reportError, setErrorManager, setFilter, setFormatter, setLevel`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### StdOutHandler

    public StdOutHandler()

Method Detail

### publish

    public void publish(java.util.logging.LogRecord record)

  Overrides:
    `publish` in class `java.util.logging.StreamHandler`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.